nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

ForceSel

Enum ForceSel 

#[repr(u8)]
pub enum ForceSel { LOCAL = 0, MASTER = 1, LOCAL_RELOAD = 2, MASTER_RELOAD = 3, LOCAL_SYNC = 4, MASTER_SYNC = 5, EXT_FORCE = 6, EXT_SYNC = 7, }

Variants



LOCAL = 0

The local force signal, CTRL2[FORCE], from this submodule is used to force updates.



MASTER = 1

The master force signal from submodule 0 is used to force updates. This setting should not be used in submodule 0 as it will hold the FORCE OUTPUT signal to logic 0.



LOCAL_RELOAD = 2

The local reload signal from this submodule is used to force updates without regard to the state of LDOK.



MASTER_RELOAD = 3

The master reload signal from submodule0 is used to force updates if LDOK is set. This setting should not be used in submodule0 as it will hold the FORCE OUTPUT signal to logic 0.



LOCAL_SYNC = 4

The local sync signal from this submodule is used to force updates.



MASTER_SYNC = 5

The master sync signal from submodule0 is used to force updates. This setting should not be used in submodule0 as it will hold the FORCE OUTPUT signal to logic 0.



EXT_FORCE = 6

The external force signal, EXT_FORCE, from outside the PWM module causes updates.



EXT_SYNC = 7

The external sync signal, EXT_SYNC, from outside the PWM module causes updates.

Implementations

Source

impl ForceSel

pub const fn from_bits(val: u8) -> ForceSel

pub const fn to_bits(self) -> u8