#[repr(u8)]pub enum Sm1out45 {
LOGIC_0 = 0,
LOGIC_1 = 1,
}Variants
LOGIC_0 = 0
A logic 0 is supplied to the deadtime generator of submodule 1 instead of PWM45.
LOGIC_1 = 1
A logic 1 is supplied to the deadtime generator of submodule 1 instead of PWM45.
Implementations