#[repr(u8)]pub enum Monpll {
NOTLOCKED_DO_NOT_MON_PLL = 0,
NOTLOCKED_MON_PLL = 1,
LOCKED_DO_NOT_MON_PLL = 2,
LOCKED_MON_PLL = 3,
}Variants
NOTLOCKED_DO_NOT_MON_PLL = 0
Not locked. Do not monitor PLL operation. Resetting of the fractional delay block in case of PLL losing lock will be controlled by software.
NOTLOCKED_MON_PLL = 1
Not locked. Monitor PLL operation to automatically disable the fractional delay block when the PLL encounters problems.
LOCKED_DO_NOT_MON_PLL = 2
Locked. Do not monitor PLL operation. Resetting of the fractional delay block in case of PLL losing lock will be controlled by software. These bits are write protected until the next reset.
LOCKED_MON_PLL = 3
Locked. Monitor PLL operation to automatically disable the fractional delay block when the PLL encounters problems. These bits are write protected until the next reset.
Implementations